require "box2d"

function init()
	-- create world
	world = b2.World.new(0, 0)

	-- set up debug drawing
	local debugDraw = b2.DebugDraw.new()
	world:setDebugDraw(debugDraw)
	stage:addChild(debugDraw)
	
	local radius = 30
	player = world:createBody{type = b2.DYNAMIC_BODY, bullet = true}
	player:setPosition(50, 50)
	local circle = b2.CircleShape.new(0, 0, radius) 
	player:createFixture{shape = circle}
	
	-- init line
	line = Shape.new()
	line:setLineStyle(5, 0x0000ff, 0)
	line:beginPath()
	line:moveTo(application:getContentWidth()/2, 0)
	line:lineTo(application:getContentWidth()/2, application:getContentHeight())
	line:closePath()
	line:endPath()
	local body = world:createBody{type = b2.STATIC_BODY}
	body:setAngle(line:getRotation() * math.pi/180)
	body:createFixture{shape = b2.EdgeShape.new(application:getContentWidth()/2, 0, application:getContentWidth()/2, application:getContentHeight())}
	line.body = body
	line.body.type = "line"
	stage:addChild(line)
	

	-- init rock sprite position
	xx, yy = 50, 50
	
	-- envet listener
	stage:addEventListener(Event.MOUSE_MOVE, getPosition)
	stage:addEventListener(Event.ENTER_FRAME, playerMove)
	
	-- running world
	stage:addEventListener(Event.ENTER_FRAME, onEnterFrame)
end

function onEnterFrame() 
	world:step(1/60, 8, 3)
	for i = 1, stage:getNumChildren() do
		local sprite = stage:getChildAt(i)
		if sprite.body then
			local body = sprite.body
			local bodyX, bodyY = body:getPosition()
			sprite:setPosition(bodyX, bodyY)
			sprite:setRotation(body:getAngle() * 180 / math.pi)
		end
	end
end


function getPosition(e)
	xx = e.x
	yy = e.y
end

function playerMove(e)
	local x, y = player:getPosition()
	player:setPosition(x + (xx - x) * 0.2, y + (yy - y ) * 0.2)
end

init()